16.134. cdist-type__ssh_dot_ssh(7) — cdist 4.10.11 documentation

# 16.134. cdist-type__ssh_dot_ssh(7)

## 16.134.1. NAME

cdist-type__ssh_dot_ssh - Manage .ssh directory

## 16.134.2. DESCRIPTION

Adds or removes .ssh directory to a user home.

This type is being used by __ssh_authorized_keys.

## 16.134.3. OPTIONAL PARAMETERS

state
  if the directory should be 'present' or 'absent', defaults to 'present'.

## 16.134.4. EXAMPLES

    # Ensure root has ~/.ssh with the right permissions
    __ssh_dot_ssh root

    # Nico does not need ~/.ssh anymore
    __ssh_dot_ssh nico --state absent

## 16.134.5. SEE ALSO

cdist-type__ssh_authorized_keys(7)

## 16.134.6. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>

## 16.134.7. COPYING

Copyright (C) 2014 Nico Schottelius. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.